# MRDevs Tools Development Guide

## Build & Installation Commands
- `bin/bootstrap.sh` - Install basic tools and container management
- `bin/update.sh` - Update development environment
- `bin/cortana_install.sh` - Install Claude Code CLI
- `bin/cortana_install.sh -u` - Uninstall Claude Code CLI

## Code Style Guidelines
- **Shell Scripts**:
  - Add license header with copyright info (AGPL)
  - Include Modified date in comments
  - Use functions for modularity
  - Follow consistent variable naming (`UPPERCASE` for constants)
  - Document function purpose with comments
  - Include usage examples in script headers
  - Handle errors with proper exit codes

## Development Practices
- Use `bin/lib/base.lib` for common functions
- Use `bin/lib/developers.lib` for developers functions
- Use `bin/lib/clonsole.lib` for dialog functions
- Message files stored in `bin/msg/` (multilingual support)
- Configuration in `bin/config/` directory
- Use git commit messages with prefixes: [ADDED], [IMPROVED], [FIXED], [SOPS], [INIT]
- Prefer podman over docker for container management
- All shell scripts (.sh) and Python scripts (.py) must be placed in the `bin/` directory unless explicitly specified otherwise

## Authorship Policy
- Use `bin/config/python.header` how example to python comment header
- Use `bin/config/bash.header` how example to bash comment header
- For new projects created by Claude Code, use author: "Cortana Rosero One <cortana@rosero.one>"
- Include reference indicating generation by Claude Code and the version used
- Example header comment for Cortana:
  ```
  # [Author] Cortana Rosero One <cortana@rosero.one>
  # [Generated] Created by Claude Code (claude-3-7-sonnet-20250219)
  ```
